@@ -1,12 +1,13 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
-from simba.read_config_unit_tests import (check_int,
-                                             check_str,
-                                             check_float,
-                                             read_config_entry,
-                                             read_config_file)
+from simba.read_config_unit_tests import (read_config_entry,
+                                          read_config_file,
+                                          check_if_dir_exists,
+                                          check_if_filepath_list_is_empty,
+                                          read_project_path_and_file_type)
 from simba.train_model_functions import get_all_clf_names
 import os, glob
+from simba.enums import ReadConfig, Paths, Dtypes
 from simba.rw_dfs import read_df, save_df
 from simba.misc_tools import get_fn_ext
 import pandas as pd
@@ -46,18 +47,17 @@ class BorisAppender(object):
 
 
         self.config = read_config_file(config_path)
-        self.project_path = read_config_entry(self.config, 'General settings', 'project_path', data_type='folder_path')
-        self.file_type = read_config_entry(self.config, 'General settings', 'workflow_file_type', 'str', 'csv')
-        self.in_features_dir = os.path.join(self.project_path, 'csv', 'features_extracted')
-        self.out_dir = os.path.join(self.project_path, 'csv', 'targets_inserted')
-        self.model_cnt = read_config_entry(self.config, 'SML settings', 'No_targets', 'int')
+        self.project_path, self.file_type = read_project_path_and_file_type(config=self.config)
+        self.in_features_dir = os.path.join(self.project_path, Paths.FEATURES_EXTRACTED_DIR.value)
+        self.out_dir = os.path.join(self.project_path, Paths.TARGETS_INSERTED_DIR.value)
+        self.model_cnt = read_config_entry(self.config, ReadConfig.SML_SETTINGS.value, ReadConfig.TARGET_CNT.value, Dtypes.INT.value)
+        check_if_dir_exists(boris_folder)
         self.in_boris_dir = boris_folder
         self.clf_names = get_all_clf_names(config=self.config, target_cnt=self.model_cnt)
         self.feature_files_found = glob.glob(self.in_features_dir + '/*.' + self.file_type)
         self.boris_files_found = glob.glob(self.in_boris_dir + '/*.csv')
-        if len(self.boris_files_found) == 0:
-            print('SIMBA ERROR: 0 BORIS CSV files found in {} directory'.format(self.in_boris_dir))
-            raise ValueError()
+        check_if_filepath_list_is_empty(filepaths=self.boris_files_found,
+                                        error_msg='SIMBA ERROR: 0 BORIS CSV files found in {} directory'.format(self.in_boris_dir))
         print('Processing BORIS for {} file(s)...'.format(str(len(self.feature_files_found))))
 
     def create_boris_master_file(self):
@@ -71,9 +71,9 @@ class BorisAppender(object):
         """
         self.master_boris_df_list = []
         for file_cnt, file_path in enumerate(self.boris_files_found):
-            _, video_name, _ = get_fn_ext(file_path)
-            boris_df = pd.read_csv(file_path)
             try:
+                _, video_name, _ = get_fn_ext(file_path)
+                boris_df = pd.read_csv(file_path)
                 index = (boris_df[boris_df['Observation id'] == "Time"].index.values)
                 boris_df = pd.read_csv(file_path, skiprows=range(0, int(index + 1)))
                 boris_df = boris_df.loc[:, ~boris_df.columns.str.contains('^Unnamed')]
@@ -81,8 +81,9 @@ class BorisAppender(object):
                 _, video_base_name, _ = get_fn_ext(boris_df.loc[0, 'Media file path'])
                 boris_df['Media file path'] = video_base_name
                 self.master_boris_df_list.append(boris_df)
-            except:
+            except Exception as e:
                 print('SIMBA WARNING: {} is not a valid BORIS file and is skipped. See the SimBA GitHub repository for expected file format'.format(file_path))
+                print(e.args)
         self.master_boris_df = pd.concat(self.master_boris_df_list, axis=0).reset_index(drop=True)
         print('Found {} annotated behaviors in {} files with {} directory'.format(str(len(self.master_boris_df['Behavior'].unique())), len(self.boris_files_found), self.in_boris_dir))
         print('The following behavior annotations where detected in the boris directory:')
@@ -114,8 +115,9 @@ class BorisAppender(object):
             if (len(vid_annotations) == 0):
                 print('SIMBA WARNING: No BORIS annotations detected for SimBA classifier(s) named {} for video {}'.format(str(self.clf_names), self.video_name))
             else:
-                video_fps = vid_annotations.loc[0, 'FPS']
+                video_fps = vid_annotations['FPS'].values[0]
                 for clf in self.clf_names:
+                    self.clf = clf
                     clf_annotations = vid_annotations[(vid_annotations['Behavior'] == clf)]
                     clf_annotations_start = clf_annotations[clf_annotations['Status'] == 'START'].reset_index(drop=True)
                     clf_annotations_stop = clf_annotations[clf_annotations['Status'] == 'STOP'].reset_index(drop=True)
@@ -125,6 +127,7 @@ class BorisAppender(object):
                         raise ValueError()
                     self.clf_annotations = clf_annotations_start['Time'].to_frame().rename(columns={'Time': "START"})
                     self.clf_annotations['STOP'] = clf_annotations_stop['Time']
+                    self.clf_annotations = self.clf_annotations.apply(pd.to_numeric)
                     results = self.__check_non_overlapping_annotations()
                     if len(results) > 0:
                         print('SIMBA BORIS ERROR: The BORIS annotations for behavior {} in video {} contains '
@@ -154,10 +157,10 @@ class BorisAppender(object):
         save_df(self.out_df, self.file_type, save_path)
         print('Saved BORIS annotations for video {}...'.format(self.video_name))
 
-# test = BorisAppender(config_path='/Users/simon/Desktop/troubleshooting/BORIS_/project_folder/project_config.ini', boris_folder=r'/Users/simon/Desktop/troubleshooting/BORIS_/boris_import')
+# test = BorisAppender(config_path='/Users/simon/Desktop/envs/troubleshooting/two_black_animals_14bp/project_folder/project_config.ini',
+#                      boris_folder='/Users/simon/Downloads/FIXED')
 # test.create_boris_master_file()
 # test.append_boris()
-
 # test = BorisAppender(config_path='/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini', boris_folder=r'/Users/simon/Desktop/troubleshooting/train_model_project/boris_import')
 # test.create_boris_master_file()
 # test.append_boris()
