@@ -1,6 +1,7 @@
 from datetime import datetime
 from simba.read_config_unit_tests import (read_config_entry,
-                                          read_config_file)
+                                          read_config_file,
+                                          read_project_path_and_file_type)
 from simba.features_scripts.unit_tests import (read_video_info_csv,
                                                read_video_info)
 import os
@@ -8,6 +9,7 @@ import pandas as pd
 from simba.ROI_analyzer import ROIAnalyzer
 from simba.misc_tools import (get_fn_ext,
                               SimbaTimer)
+from simba.enums import ReadConfig, Paths, DirNames, Dtypes
 from simba.rw_dfs import read_df
 import itertools
 
@@ -40,15 +42,14 @@ class ROITimebinCalculator(object):
         self.config_path, self.bin_length = config_path, bin_length
         self.date_time = datetime.now().strftime('%Y%m%d%H%M%S')
         self.config = read_config_file(config_path)
-        self.file_type = read_config_entry(self.config, 'General settings', 'workflow_file_type', 'str', 'csv')
-        self.project_path = read_config_entry(self.config, 'General settings', 'project_path', data_type='folder_path')
-        self.roi_animal_cnt = read_config_entry(config=self.config, section='ROI settings', option='no_of_animals', data_type='int')
-        self.probability_threshold = read_config_entry(config=self.config, section='ROI settings', option='probability_threshold', data_type='float',default_value=0.00)
+        self.project_path, self.file_type = read_project_path_and_file_type(config=self.config)
+        self.roi_animal_cnt = read_config_entry(config=self.config, section=ReadConfig.ROI_SETTINGS.value, option=ReadConfig.ROI_ANIMAL_CNT.value, data_type=Dtypes.INT.value)
+        self.probability_threshold = read_config_entry(config=self.config, section=ReadConfig.ROI_SETTINGS.value, option=ReadConfig.PROBABILITY_THRESHOLD.value, data_type=Dtypes.FLOAT.value,default_value=0.00)
         self.logs_path = os.path.join(self.project_path, 'logs')
         self.save_path_time = os.path.join(self.logs_path, 'ROI_time_bins_{}s_time_data_{}.csv'.format(str(bin_length), self.date_time))
         self.save_path_entries = os.path.join(self.logs_path, 'ROI_time_bins_{}s_entry_data_{}.csv'.format(str(bin_length), self.date_time))
-        self.video_info_df = read_video_info_csv(file_path=os.path.join(self.logs_path, 'video_info.csv'))
-        self.roi_analyzer = ROIAnalyzer(ini_path=self.config_path, data_path='outlier_corrected_movement_location', calculate_distances=False)
+        self.video_info_df = read_video_info_csv(file_path=os.path.join(self.project_path, Paths.VIDEO_INFO.value))
+        self.roi_analyzer = ROIAnalyzer(ini_path=self.config_path, data_path=DirNames.OUTLIER_MOVEMENT_LOCATION.value, calculate_distances=False)
         self.roi_analyzer.read_roi_dfs()
         self.roi_analyzer.analyze_ROIs()
         self.shape_names = self.roi_analyzer.shape_names
