@@ -1,7 +1,16 @@
-from simba.read_config_unit_tests import read_config_entry, read_config_file, check_int
-from simba.tkinter_functions import DropDownMenu, Entry_Box
-from simba.drop_bp_cords import create_body_part_dictionary, getBpNames
-from simba.misc_tools import check_multi_animal_status, get_fn_ext, find_video_of_file, create_single_color_lst
+from simba.read_config_unit_tests import (read_config_entry,
+                                          read_config_file,
+                                          check_int,
+                                          read_project_path_and_file_type)
+from simba.tkinter_functions import (DropDownMenu,
+                                     Entry_Box)
+from simba.drop_bp_cords import (create_body_part_dictionary,
+                                 getBpNames)
+from simba.misc_tools import (check_multi_animal_status,
+                              get_fn_ext,
+                              get_named_colors)
+from simba.enums import ReadConfig, Dtypes, Formats
+
 import os, glob
 import pickle
 from tkinter import *
@@ -34,31 +43,14 @@ class BoundaryMenus(object):
 
         self.config_path = config_path
         self.config = read_config_file(self.config_path)
-        self.project_path = read_config_entry(self.config, 'General settings', 'project_path', data_type='folder_path')
+        self.project_path, _ = read_project_path_and_file_type(config=self.config)
         self.video_dir = os.path.join(self.project_path, 'videos')
-        self.animal_cnt = read_config_entry(self.config, 'General settings', 'animal_no', 'int')
+        self.no_animals = read_config_entry(self.config, ReadConfig.GENERAL_SETTINGS.value, ReadConfig.ANIMAL_CNT.value, Dtypes.INT.value)
         self.boundary_main_frm = Toplevel()
         self.boundary_main_frm.minsize(750, 300)
         self.boundary_main_frm.wm_title("SIMBA ANCHORED ROI (BOUNDARY BOXES ANALYSIS)")
-        self.named_shape_colors = {'White': (255, 255, 255),
-                                   'Grey': (220, 200, 200),
-                                   'Red': (0, 0, 255),
-                                   'Dark-red': (0, 0, 139),
-                                   'Maroon': (0, 0, 128),
-                                   'Orange': (0, 165, 255),
-                                   'Dark-orange': (0, 140, 255),
-                                   'Coral': (80, 127, 255),
-                                   'Chocolate': (30, 105, 210),
-                                   'Yellow': (0, 255, 255),
-                                   'Green': (0, 128, 0),
-                                   'Dark-grey': (105, 105, 105),
-                                   'Light-grey': (192, 192, 192),
-                                   'Pink': (178, 102, 255),
-                                   'Lime': (204, 255, 229),
-                                   'Purple': (255, 51, 153),
-                                   'Cyan': (255, 255, 102)}
-        self.settings_frm = LabelFrame(self.boundary_main_frm, text='SETTINGS', font=('Helvetica', 15, 'bold'), pady=5, padx=15)
-        self.no_animals = read_config_entry(self.config, 'General settings', 'animal_no', 'int')
+        self.named_shape_colors = get_named_colors()
+        self.settings_frm = LabelFrame(self.boundary_main_frm, text='SETTINGS', font=Formats.LABELFRAME_HEADER_FORMAT.value, pady=5, padx=15)
         self.multi_animal_status, self.multi_animal_id_lst = check_multi_animal_status(self.config, self.no_animals)
         self.x_cols, self.y_cols, self.pcols = getBpNames(config_path)
         self.animal_bp_dict = create_body_part_dictionary(self.multi_animal_status, list(self.multi_animal_id_lst), self.no_animals, list(self.x_cols), list(self.y_cols), [], [])
@@ -78,7 +70,7 @@ class BoundaryMenus(object):
         self.find_boundaries_frm.minsize(750, 300)
         self.find_boundaries_frm.wm_title("FIND ANIMAL BOUNDARIES")
         self.find_boundaries_frm.lift()
-        self.select_shape_type_frm = LabelFrame(self.find_boundaries_frm, text='SELECT SHAPE TYPE', font=('Helvetica', 15, 'bold'), pady=5, padx=15)
+        self.select_shape_type_frm = LabelFrame(self.find_boundaries_frm, text='SELECT SHAPE TYPE', font=Formats.LABELFRAME_HEADER_FORMAT.value, pady=5, padx=15)
         self.shape_types = ['ENTIRE ANIMAL', 'SINGLE BODY-PART SQUARE', 'SINGLE BODY-PART CIRCLE']
         self.shape_dropdown = DropDownMenu(self.select_shape_type_frm,'SELECT SHAPE TYPE',self.shape_types,'15')
         self.shape_dropdown.setChoices(self.shape_types[0])
@@ -91,7 +83,7 @@ class BoundaryMenus(object):
         if hasattr(self, 'boundary_settings'):
             self.boundary_settings.destroy()
         self.selected_shape_type = self.shape_dropdown.getChoices()
-        self.boundary_settings = LabelFrame(self.find_boundaries_frm, text='BOUNDARY SETTINGS', font=('Helvetica', 15, 'bold'), pady=5, padx=15)
+        self.boundary_settings = LabelFrame(self.find_boundaries_frm, text='BOUNDARY SETTINGS', font=Formats.LABELFRAME_HEADER_FORMAT.value, pady=5, padx=15)
         boundary_settings_row_cnt = 1
         if (self.selected_shape_type == 'SINGLE BODY-PART SQUARE') | (self.selected_shape_type == 'SINGLE BODY-PART CIRCLE'):
             self.animals = {}
@@ -156,11 +148,11 @@ class BoundaryMenus(object):
         self.viz_boundaries_frm = Toplevel()
         self.viz_boundaries_frm.minsize(600, 150)
         self.viz_boundaries_frm.wm_title("VISUALIZE ANIMAL BOUNDARIES")
-        self.video_settings_frm = LabelFrame(self.viz_boundaries_frm, text='SETTINGS', font=('Helvetica', 15, 'bold'), pady=5, padx=15)
-        self.roi_attr_frm = LabelFrame(self.viz_boundaries_frm, text='ROI ATTRIBUTES', font=('Helvetica', 15, 'bold'), pady=5, padx=15)
+        self.video_settings_frm = LabelFrame(self.viz_boundaries_frm, text='SETTINGS', font=Formats.LABELFRAME_HEADER_FORMAT.value, pady=5, padx=15)
+        self.roi_attr_frm = LabelFrame(self.viz_boundaries_frm, text='ROI ATTRIBUTES', font=Formats.LABELFRAME_HEADER_FORMAT.value, pady=5, padx=15)
         self.select_video_dropdown = DropDownMenu(self.video_settings_frm, 'SELECT VIDEO: ', sets_w_data_and_video, ' 0')
         self.select_video_dropdown.setChoices(sets_w_data_and_video[0])
-        self.run_visualize_roi = Button(self.viz_boundaries_frm, text='RUN', font=('Helvetica', 15, 'bold'), fg='blue', command=lambda: self.__run_boundary_visualization())
+        self.run_visualize_roi = Button(self.viz_boundaries_frm, text='RUN', font=Formats.LABELFRAME_HEADER_FORMAT.value, fg='blue', command=lambda: self.__run_boundary_visualization())
         self.include_keypoints_var = BooleanVar()
         self.convert_to_grayscale_var = BooleanVar()
         self.highlight_intersections_var = BooleanVar()
@@ -178,12 +170,12 @@ class BoundaryMenus(object):
         self.run_visualize_roi.grid(row=5, column=0, sticky=NW)
         self.animal_attr_dict = {}
 
-        Label(self.roi_attr_frm, text='ANIMAL', font=('Helvetica', 12, 'bold'), width=self.max_animal_name_char + 10).grid(row=0, column=0, sticky=N)
-        Label(self.roi_attr_frm, text='ROI COLOR', font=('Helvetica', 12, 'bold'), width=self.max_animal_name_char + 10).grid(row=0, column=1, sticky=N)
-        Label(self.roi_attr_frm, text='ROI THICKNESS', font=('Helvetica', 12, 'bold'), width=self.max_animal_name_char + 10).grid(row=0, column=2, sticky=N)
-        Label(self.roi_attr_frm, text='KEY-POINT SIZE', font=('Helvetica', 12, 'bold'), width=self.max_animal_name_char + 10).grid(row=0, column=3, sticky=N)
-        Label(self.roi_attr_frm, text='HIGHLIGHT COLOR', font=('Helvetica', 12, 'bold'), width=self.max_animal_name_char + 10).grid(row=0, column=4, sticky=N)
-        Label(self.roi_attr_frm, text='HIGHLIGHT THICKNESS', font=('Helvetica', 12, 'bold'), width=self.max_animal_name_char + 10).grid(row=0, column=5, sticky=N)
+        Label(self.roi_attr_frm, text='ANIMAL', font=Formats.LABELFRAME_HEADER_FORMAT.value, width=self.max_animal_name_char + 10).grid(row=0, column=0, sticky=N)
+        Label(self.roi_attr_frm, text='ROI COLOR', font=Formats.LABELFRAME_HEADER_FORMAT.value, width=self.max_animal_name_char + 10).grid(row=0, column=1, sticky=N)
+        Label(self.roi_attr_frm, text='ROI THICKNESS', font=Formats.LABELFRAME_HEADER_FORMAT.value, width=self.max_animal_name_char + 10).grid(row=0, column=2, sticky=N)
+        Label(self.roi_attr_frm, text='KEY-POINT SIZE', font=Formats.LABELFRAME_HEADER_FORMAT.value, width=self.max_animal_name_char + 10).grid(row=0, column=3, sticky=N)
+        Label(self.roi_attr_frm, text='HIGHLIGHT COLOR', font=Formats.LABELFRAME_HEADER_FORMAT.value, width=self.max_animal_name_char + 10).grid(row=0, column=4, sticky=N)
+        Label(self.roi_attr_frm, text='HIGHLIGHT THICKNESS', font=Formats.LABELFRAME_HEADER_FORMAT.value, width=self.max_animal_name_char + 10).grid(row=0, column=5, sticky=N)
         for cnt, animal_name in enumerate(self.animal_bp_dict.keys()):
             self.animal_attr_dict[animal_name] = {}
             self.animal_attr_dict[animal_name]['label'] = Label(self.roi_attr_frm, text=animal_name, width=self.max_animal_name_char)
@@ -255,8 +247,8 @@ class BoundaryMenus(object):
         self.statistics_frm = Toplevel()
         self.statistics_frm.minsize(400, 150)
         self.statistics_frm.wm_title("ANIMAL ANCHORED ROI STATISTICS")
-        self.settings_frm = LabelFrame(self.statistics_frm, text='SETTINGS', font=('Helvetica', 15, 'bold'), pady=5, padx=15)
-        self.file_type_frm = LabelFrame(self.statistics_frm, text='OUTPUT FILE TYPE', font=('Helvetica', 15, 'bold'), pady=5, padx=15)
+        self.settings_frm = LabelFrame(self.statistics_frm, text='SETTINGS', font=Formats.LABELFRAME_HEADER_FORMAT.value, pady=5, padx=15)
+        self.file_type_frm = LabelFrame(self.statistics_frm, text='OUTPUT FILE TYPE', font=Formats.LABELFRAME_HEADER_FORMAT.value, pady=5, padx=15)
         self.roi_intersections_var = BooleanVar(value=True)
         self.roi_keypoint_intersections_var = BooleanVar(value=True)
         self.roi_intersections_cb = Checkbutton(self.settings_frm, text='ROI-ROI INTERSECTIONS', variable=self.roi_intersections_var, command=None)
