@@ -1,15 +1,17 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
-import pandas as pd
 import os, glob
 import numpy as np
-from configparser import ConfigParser, NoOptionError
 import pandas as pd
 from simba.rw_dfs import read_df, save_df
-from simba.read_config_unit_tests import read_config_entry, read_config_file
-from simba.features_scripts.unit_tests import read_video_info, read_video_info_csv
-from simba.drop_bp_cords import get_fn_ext
-from simba.drop_bp_cords import get_workflow_file_format
+from simba.read_config_unit_tests import (read_config_entry,
+                                          read_config_file,
+                                          check_if_filepath_list_is_empty,
+                                          read_project_path_and_file_type)
+from simba.features_scripts.unit_tests import (read_video_info,
+                                               read_video_info_csv)
+from simba.misc_tools import SimbaTimer
+from simba.enums import ReadConfig, Paths
 
 
 class ImportEthovision(object):
@@ -38,24 +40,25 @@ class ImportEthovision(object):
                  folder_path: str):
 
         print('Appending Ethovision annotations...')
+        self.timer = SimbaTimer()
+        self.timer.start_timer()
         self.config = read_config_file(config_path)
         self.files_found = glob.glob(folder_path + '/*.xlsx') + glob.glob(folder_path + '/*.xls')
         self.files_found = [x for x in self.files_found if '~$' not in x]
-        if len(self.files_found) == 0:
-            print('SIMBA ERROR: No ethovision xlsx or xls files found in {}'.format(str(folder_path)))
-            raise ValueError('SIMBA ERROR: No ethovision xlsx or xls files found in {}'.format(str(folder_path)))
-        model_nos = self.config.getint('SML settings', 'no_targets')
+        check_if_filepath_list_is_empty(filepaths=self.files_found,
+                                        error_msg='SIMBA ERROR: No Ethovision xlsx or xls files found in {}'.format(str(folder_path)))
+        model_nos = self.config.getint(ReadConfig.SML_SETTINGS.value, ReadConfig.TARGET_CNT.value)
         self.classifier_names = []
         for i in range(model_nos):
-            self.classifier_names.append(self.config.get('SML settings', 'target_name_' + str(i + 1)))
-        self.project_path = self.config.get('General settings', 'project_path')
-        self.vid_config_path = os.path.join(self.project_path, 'logs', 'video_info.csv')
-        self.features_folder = os.path.join(self.project_path, 'csv', 'features_extracted')
-        self.targets_insert_folder_path = os.path.join(self.project_path, 'csv', 'targets_inserted')
+            self.classifier_names.append(self.config.get(ReadConfig.SML_SETTINGS.value, 'target_name_' + str(i + 1)))
+        self.project_path, self.workflow_file_format = read_project_path_and_file_type(self.config)
+        self.vid_config_path = os.path.join(self.project_path, Paths.VIDEO_INFO.value)
+        self.features_folder = os.path.join(self.project_path, Paths.FEATURES_EXTRACTED_DIR.value)
+        self.targets_insert_folder_path = os.path.join(self.project_path, Paths.TARGETS_INSERTED_DIR.value)
         self.video_config_df = read_video_info_csv(self.vid_config_path)
-        self.workflow_file_format = get_workflow_file_format(self.config)
         self.__read_files()
-        print('All Ethovision annotations added. Files with annotation are located in the project_folder/csv/targets_inserted directory.')
+        self.timer.stop_timer()
+        print('All Ethovision annotations added. Files with annotation are located in the project_folder/csv/targets_inserted directory (elapsed time: {}s)'.format(self.timer.elapsed_time_str))
 
     def __read_files(self):
         for file_path in self.files_found:
