@@ -91,6 +91,9 @@ class ExtractFeaturesFrom16bps(object):
 
     @staticmethod
     def convex_hull_calculator_mp(arr: np.array, px_per_mm: float) -> float:
+        arr = np.unique(arr, axis=0)
+        if arr.shape[0] < 3:
+            return 0
         for i in range(1, arr.shape[0]):
             if (arr[i] != arr[0]).all():
                 return ConvexHull(arr).area / px_per_mm
@@ -98,6 +101,7 @@ class ExtractFeaturesFrom16bps(object):
                 pass
         return 0
 
+
     @staticmethod
     @jit(nopython=True)
     def __count_values_in_range(data: np.array, ranges: np.array):
