@@ -92,6 +92,9 @@ class ExtractFeaturesFrom7bps(object):
 
     @staticmethod
     def convex_hull_calculator_mp(arr: np.array, px_per_mm: float) -> float:
+        arr = np.unique(arr, axis=0)
+        if arr.shape[0] < 3:
+            return 0
         for i in range(1, arr.shape[0]):
             if (arr[i] != arr[0]).all():
                 return ConvexHull(arr).area / px_per_mm
