@@ -84,6 +84,9 @@ class ExtractFeaturesFrom8bps(object):
 
     @staticmethod
     def convex_hull_calculator_mp(arr: np.array, px_per_mm: float) -> float:
+        arr = np.unique(arr, axis=0)
+        if arr.shape[0] < 3:
+            return 0
         for i in range(1, arr.shape[0]):
             if (arr[i] != arr[0]).all():
                 return ConvexHull(arr).area / px_per_mm
@@ -151,8 +154,8 @@ class ExtractFeaturesFrom8bps(object):
                 animal_frm = np.reshape(animal_frm, (-1, 2))
                 animal_dists = scipy.spatial.distance.cdist(animal_frm, animal_frm, metric='euclidean')
                 animal_dists = animal_dists[animal_dists != 0]
-                self.hull_dict['M1_largest_euclidean_distance_hull'].append(np.amax(animal_dists) / self.px_per_mm)
-                self.hull_dict['M1_smallest_euclidean_distance_hull'].append(np.amin(animal_dists) / self.px_per_mm)
+                self.hull_dict['M1_largest_euclidean_distance_hull'].append(np.amax(animal_dists, initial=0) / self.px_per_mm)
+                self.hull_dict['M1_smallest_euclidean_distance_hull'].append(np.amin(animal_dists, initial=0) / self.px_per_mm)
                 self.hull_dict['M1_mean_euclidean_distance_hull'].append(np.mean(animal_dists) / self.px_per_mm)
                 self.hull_dict['M1_sum_euclidean_distance_hull'].append(np.sum(animal_dists) / self.px_per_mm)
             for k, v in self.hull_dict.items():
@@ -337,5 +340,5 @@ class ExtractFeaturesFrom8bps(object):
 
         print('SIMBA COMPLETE: All features extracted (elapsed time: {}s). Results stored in project_folder/csv/features_extracted directory'.format(str(int(session_time))))
 
-# test = ExtractFeaturesFrom7bps(config_path='/Users/simon/Desktop/train_model_project/project_folder/project_config.ini')
+# test = ExtractFeaturesFrom8bps(config_path='/Users/simon/Desktop/envs/troubleshooting/one_black_animal/project_folder/project_config.ini')
 # test.extract_features()
\ No newline at end of file
