@@ -2,7 +2,9 @@ __author__ = "Simon Nilsson", "JJ Choong"
 
 import pandas as pd
 from simba.drop_bp_cords import *
+from simba.read_config_unit_tests import read_config_file
 import numpy as np
+from simba.enums import ReadConfig
 from simba.misc_tools import check_multi_animal_status
 
 
@@ -31,18 +33,14 @@ class Interpolate(object):
 
     '''
 
-
-
     def __init__(self,
                  config_file_path: str,
                  in_file: pd.DataFrame):
         self.in_df = in_file
-        configFile = str(config_file_path)
-        config = ConfigParser()
-        config.read(configFile)
+        config = read_config_file(ini_path=config_file_path)
         Xcols, Ycols, Pcols = getBpNames(config_file_path)
         self.columnHeaders = getBpHeaders(config_file_path)
-        noAnimals = config.getint('General settings', 'animal_no')
+        noAnimals = config.getint(ReadConfig.GENERAL_SETTINGS.value, ReadConfig.ANIMAL_CNT.value)
         _, multiAnimalIDList = check_multi_animal_status(config, noAnimals)
         multiAnimalStatus = True
         self.multiAnimalIDList = [x for x in multiAnimalIDList if x]
