@@ -1,11 +1,10 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
 import configparser
-
-import numpy as np
-
-from simba.drop_bp_cords import get_fn_ext, get_workflow_file_format
-from simba.rw_dfs import read_df, save_df
+from simba.drop_bp_cords import (get_fn_ext,
+                                 get_workflow_file_format)
+from simba.rw_dfs import (read_df,
+                          save_df)
 import cv2
 from pylab import *
 import os, glob
@@ -19,16 +18,19 @@ from pathlib import Path
 import io
 import PIL
 import imutils
-from numba import jit
-from configparser import ConfigParser, MissingSectionHeaderError
+from numba import jit, prange
+from configparser import (ConfigParser,
+                          MissingSectionHeaderError)
 import multiprocessing
 from simba.read_config_unit_tests import (check_file_exist_and_readable,
                                           read_config_entry,
-                                          check_int)
+                                          check_int,
+                                          check_if_filepath_list_is_empty)
+from simba.enums import ReadConfig, Formats
 import shutil
 import platform
 import pickle
-import subprocess
+import pathlib
 from datetime import datetime
 from simba.extract_frames_fast import video_to_frames
 import simba
@@ -209,13 +211,13 @@ def line_length_numba(left_ear_array: np.array,
 
     Parameters
     ----------
-    left_ear_array: np.array
+    left_ear_array: array
         left ear coordinates of observing animal.
-    right_ear_array: np.array
+    right_ear_array: array
         right ear coordinates of observing animal.
-    nose_array: np.array
+    nose_array: array
         nose coordinates of observing animal.
-    target_array: np.array
+    target_array: array
         The location of the target coordinates.
 
     Returns
@@ -319,7 +321,7 @@ def find_video_of_file(video_dir: str,
             return_path = file_path
 
     if return_path is None:
-        print('SIMBA WARNING: SimBA could not find a video file resenting {} in the project video directory'.format(str(filename)))
+        print('SIMBA WARNING: SimBA could not find a video file representing {} in the project video directory'.format(str(filename)))
     return return_path
 
 
@@ -348,7 +350,7 @@ def smooth_data_gaussian(config: configparser.ConfigParser,
     except:
         print('Gaussian smoothing failed for video {}. Time window parameter {} can not be interpreted as an integer.'.format(str(os.path.basename(file_path)), str(time_window_parameter)))
     _, filename, _ = get_fn_ext(file_path)
-    project_dir = config.get('General settings', 'project_path')
+    project_dir = config.get(ReadConfig.GENERAL_SETTINGS.value, ReadConfig.PROJECT_PATH.value)
     video_dir = os.path.join(project_dir, 'videos')
     video_file_path = find_video_of_file(video_dir, filename)
     file_format = get_workflow_file_format(config)
@@ -405,7 +407,7 @@ def smooth_data_savitzky_golay(config: configparser.ConfigParser,
             'Savitzky-Golay smoothing failed for video {}. The specified time window parameter {} can not be interpreted as an integer.'.format(
                 str(os.path.basename(file_path)), str(time_window_parameter)))
     _, filename, _ = get_fn_ext(file_path)
-    project_dir = config.get('General settings', 'project_path')
+    project_dir = config.get(ReadConfig.GENERAL_SETTINGS.value, ReadConfig.PROJECT_PATH.value)
     video_dir = os.path.join(project_dir, 'videos')
     video_file_path = find_video_of_file(video_dir, filename)
     file_format = get_workflow_file_format(config)
@@ -544,7 +546,7 @@ def create_gantt_img(bouts_df: pd.DataFrame,
 def resize_gantt(gantt_img: np.array,
                  img_height: int):
     """
-    Helper to resize a image in np.array format.
+    Helper to resize a image in array format.
     """
 
     return imutils.resize(gantt_img, height=img_height)
@@ -671,7 +673,9 @@ def read_config_file(ini_path: str):
     return config
 
 def create_single_color_lst(pallete_name: str,
-                            increments: int):
+                            increments: int,
+                            as_rgb_ratio: bool=False,
+                            as_hex: bool=False):
     """
     Helper to create a color palette of bgr colors in a list.
     Parameters
@@ -686,13 +690,17 @@ def create_single_color_lst(pallete_name: str,
     color_lst: list
 
     """
-
+    if as_hex:
+        as_rgb_ratio = True
     cmap = cm.get_cmap(pallete_name, increments + 1)
     color_lst = []
     for i in range(cmap.N):
         rgb = list((cmap(i)[:3]))
-        rgb = [i * 255 for i in rgb]
+        if not as_rgb_ratio:
+            rgb = [i * 255 for i in rgb]
         rgb.reverse()
+        if as_hex:
+            rgb = matplotlib.colors.to_hex(rgb)
         color_lst.append(rgb)
     return color_lst
 
@@ -700,14 +708,14 @@ def detect_bouts(data_df: pd.DataFrame,
                  target_lst: list,
                  fps: int):
     """
-    Helper to detect all behavior bouts for a list of classifiers
+    Helper to detect all behavior bouts for a list of classifiers, or e.g., bouts of being within ROIs.
 
     Parameters
     ----------
     data_df: pd.DataFrame
         Pandas Dataframe with classifier prediction data.
     target_lst: list
-        List of classifier names. E.g., ['Attack', 'Sniffing', 'Grooming']
+        Classifier names. E.g., ['Attack', 'Sniffing', 'Grooming'] or ROIs
     fps: int
         The fps of the input video.
 
@@ -771,7 +779,7 @@ def determine_chunksize_for_imap(data_df_len: int=None,
 
 def tabulate_clf_info(clf_path: str):
     """
-    Helper to print the hyperparameters and creation date of a pickled classifier.
+    Helper to print the hyper-parameters and creation date of a pickled classifier.
 
     Parameters
     ----------
@@ -913,8 +921,8 @@ def archive_processed_files(config_path: str,
     """
 
     config = read_config_file(config_path)
-    file_type = read_config_entry(config, 'General settings', 'workflow_file_type', 'str', 'csv')
-    project_path = read_config_entry(config, 'General settings', 'project_path', data_type='folder_path')
+    file_type = read_config_entry(config, ReadConfig.GENERAL_SETTINGS.value, ReadConfig.FILE_TYPE.value, 'str', 'csv')
+    project_path = read_config_entry(config, ReadConfig.GENERAL_SETTINGS.value, ReadConfig.PROJECT_PATH.value, data_type=ReadConfig.FOLDER_PATH.value)
     videos_dir = os.path.join(project_path, 'videos')
     csv_dir = os.path.join(os.path.dirname(config_path), 'csv')
     log_path = os.path.join(project_path, 'logs')
@@ -960,8 +968,7 @@ def archive_processed_files(config_path: str,
     print('SIMBA COMPLETE: Archiving completed.')
 
 def get_color_dict():
-    return {'White': (255, 255, 255),
-            'Grey': (220, 200, 200),
+    return {'Grey': (220, 200, 200),
             'Red': (0, 0, 255),
             'Dark-red': (0, 0, 139),
             'Maroon': (0, 0, 128),
@@ -976,8 +983,32 @@ def get_color_dict():
             'Pink': (178, 102, 255),
             'Lime': (204, 255, 229),
             'Purple': (255, 51, 153),
-            'Cyan': (255, 255, 102)}
+            'Cyan': (255, 255, 102),
+            'White': (255, 255, 255),
+            'Black': (0, 0, 0)}
 
+def get_named_colors():
+    return ['red',
+            'black',
+            'green',
+            'pink',
+            'orange',
+            'blue',
+            'purple',
+            'lavender',
+            'grey',
+            'sienna',
+            'tomato',
+            'azure',
+            'crimson',
+            'aqua',
+            'plum',
+            'teal',
+            'maroon',
+            'lime',
+            'coral',
+            'deeppink',
+            'white']
 
 class SimbaTimer(object):
     def start_timer(self):
@@ -990,3 +1021,254 @@ class SimbaTimer(object):
             self.elapsed_time = round(time.time() - self.timer, 4)
             self.elapsed_time_str = str(self.elapsed_time)
 
+
+def concatenate_videos_in_folder(in_folder: str,
+                                 save_path: str,
+                                 video_format: str='mp4',
+                                 remove_splits: bool=True) -> None:
+    """
+    Helper to  concatenate (temporally) all video files in a folder into a
+    single video.
+
+    Parameters
+    ----------
+    in_folder: str
+        Path to folder holding un-concatenated video files.
+    save_path: str
+        Path to the saved the output file.
+    """
+
+    timer = SimbaTimer()
+    timer.start_timer()
+    files = glob.glob(in_folder + '/*.{}'.format(video_format))
+    check_if_filepath_list_is_empty(filepaths=files,
+                                    error_msg='SIMBA ERROR: Cannot join videos in {}. The directory contain ZERO files.'.format(in_folder))
+    files.sort(key=lambda f: int(re.sub('\D', '', f)))
+    temp_txt_path = pathlib.Path(in_folder, 'files.txt')
+    with open(temp_txt_path, 'w') as f:
+        for file in files:
+            f.write("file '" + str(pathlib.Path(file)) + "'\n")
+    if os.path.exists(save_path): os.remove(save_path)
+    returned = os.system('ffmpeg -f concat -safe 0 -i "{}" "{}" -c copy -hide_banner -loglevel info'.format(temp_txt_path, save_path))
+    while True:
+        if returned != 0:
+            pass
+        else:
+            if remove_splits:
+                remove_a_folder(folder_dir=in_folder)
+            break
+    timer.stop_timer()
+    print('Video concatenated (elapsed time: {}s)'.format(timer.elapsed_time_str))
+
+def find_all_videos_in_directory(directory: str,
+                                 as_dict: bool=False,
+                                 video_formats: tuple = ('.avi', '.mp4', '.mov', '.flv', '.m4v')):
+    """
+    Helper to return list of all video file paths in a directory
+
+    Parameters
+    ----------
+    directory: str
+        Directory to search.
+    video_formats: tuple
+        Allowed video formats.
+    as_dict: bool
+        Returns dictionary in format {'Video_1': /MyvideoPath/Video_1.mp4}
+
+    Parameters
+    ----------
+    list or dict
+    """
+
+
+    video_lst = []
+    for i in os.listdir(directory):
+        if i.lower().endswith(video_formats):
+            video_lst.append(i)
+    if not video_lst:
+        video_lst.append('No videos found')
+        print('SIMBA WARNING: No videos found in directory ({})'.format(directory))
+
+
+    if video_lst and as_dict:
+        video_dict = {}
+        for video_name in video_lst:
+            video_path = os.path.join(directory, video_name)
+            _, name, _ = get_fn_ext(filepath=video_path)
+            video_dict[name] = video_path
+        return video_dict
+
+    return video_lst
+
+
+@jit(nopython=True)
+def framewise_euclidean_distance(location_1: np.array,
+                                 location_2: np.array,
+                                 px_per_mm: float,
+                                 centimeter: bool=False) -> np.array:
+    results = np.full((location_1.shape[0]), np.nan)
+    for i in prange(location_1.shape[0]):
+        results[i] = np.linalg.norm(location_1[i] - location_2[i]) / px_per_mm
+    if centimeter:
+        results = results / 10
+    return results
+
+
+
+
+
+def copy_single_video_to_project(simba_ini_path: str,
+                                 source_path: str,
+                                 allowed_video_formats: tuple = ('avi', 'mp4')) -> None:
+
+    """ Helper to import single video file to SimBA project
+    Parameters
+    ----------
+    simba_ini_path: str
+        path to SimBA project config file in Configparser format
+    source_path: str
+        Path to video file.
+    allowed_video_formats: tuple
+        Allowed video formats. DEFAULT: avi or mp4
+    """
+
+    timer = SimbaTimer()
+    timer.start_timer()
+    _, file_name, file_ext = get_fn_ext(source_path)
+    print('Copying video {} file...'.format(file_name))
+    if file_ext[1:].lower().strip() not in allowed_video_formats:
+        print('SIMBA ERROR: SimBA works best with avi and mp4 videofiles. Or please convert your videos to mp4 or avi to continue before importing it. ')
+        raise ValueError()
+    new_filename = os.path.join(file_name + file_ext)
+    destination = os.path.join(os.path.dirname(simba_ini_path), 'videos', new_filename)
+    if os.path.isfile(destination):
+        print('SIMBA ERROR: {} already exist in SimBA project. To import, delete this video file before importing the new video file with the same name.'.format(file_name))
+        raise FileExistsError()
+    else:
+        timer.stop_timer()
+        shutil.copy(source_path, destination)
+        print('SIMBA COMPLETE: Video {} imported to SimBA project (project_folder/videos directory, elapsed time: {}s).'.format(file_name, timer.elapsed_time_str))
+
+
+def copy_multiple_videos_to_project(config_path: str,
+                                    source: str,
+                                    file_type: str,
+                                    allowed_video_formats: tuple = ('avi', 'mp4')) -> None:
+    """ Helper to import directory of videos to SimBA project
+
+    Parameters
+    ----------
+    config_path: str
+        path to SimBA project config file in Configparser format
+    source_path: str
+        Path to video file directory
+    file_type: str
+        Video format of imported videos (i.e.,.: mp4 or avi)
+    allowed_video_formats: tuple
+        Allowed video formats. DEFAULT: avi or mp4
+
+    """
+
+    if file_type.lower().strip() not in allowed_video_formats:
+        print('SIMBA ERROR: SimBA only works with avi and mp4 videofiles (Please enter mp4 or avi in entrybox). Or please convert your videos to mp4 or avi to continue. ')
+        raise ValueError()
+    video_path_lst = find_all_videos_in_directory(directory=source, video_formats=(file_type))
+    video_path_lst = [os.path.join(source, x) for x in video_path_lst]
+    if len(video_path_lst) == 0:
+        print('SIMBA ERROR: No videos found in {} directory'.format(source))
+        raise ValueError()
+
+    destination_dir = os.path.join(os.path.dirname(config_path), 'videos')
+    for file_cnt, file_path in enumerate(video_path_lst):
+        timer = SimbaTimer()
+        timer.start_timer()
+        dir_name, filebasename, file_extension = get_fn_ext(file_path)
+        file_extension = file_extension.lower()
+        newFileName = os.path.join(filebasename + file_extension)
+        dest1 = os.path.join(destination_dir, newFileName)
+        if os.path.isfile(dest1):
+            print('SIMBA WARNING: {} already exist in SimBA project. Skipping video...'.format(filebasename))
+        else:
+            shutil.copy(file_path, dest1)
+            timer.stop_timer()
+            print('{} copied to project (Video {}/{}, elapsed timer {}s)...'.format(filebasename, str(file_cnt + 1),
+                                                                                    str(len(video_path_lst)),
+                                                                                    timer.elapsed_time_str))
+    print('SIMBA COMPLETE: {} videos copied to project.'.format(str(len(video_path_lst))))
+
+
+
+def get_file_name_info_in_directory(directory: str,
+                                    file_type: str):
+    """
+    Helper to return dict of all file path with extension as values as basenames as keys.
+    E.g., ['Video_1:, 'C:\project_folder\csv\machine_results\Video_1, ...]
+
+    Parameters
+    ----------
+    directory: str
+        Directory to search.
+    video_formats: tuple
+        Allowed video formats.
+
+    Parameters
+    ----------
+    video_lst: list
+    """
+
+
+    results = {}
+    file_paths = glob.glob(directory + "/*." + file_type)
+    for file_path in file_paths:
+        _, file_name, ext = get_fn_ext(file_path)
+        results[file_name] = file_path
+
+    return results
+
+
+def split_and_group_df(df: pd.DataFrame,
+                       splits: int,
+                       include_split_order: bool=True):
+
+    data_arr = np.array_split(df, splits)
+    if include_split_order:
+        for df_cnt in range(len(data_arr)):
+            data_arr[df_cnt]['group'] = df_cnt
+    obs_per_split = len(data_arr[0])
+
+    return data_arr, obs_per_split
+
+
+def find_files_of_filetypes_in_directory(directory: str,
+                                         extensions: list,
+                                         raise_warning: bool=True):
+    """
+    Helper to find all files in a folder with specified extensions
+
+    Parameters
+    ----------
+    directory: str
+        Directory holding files
+    extensions: list
+        Accepted file extensions
+
+    Returns
+    -------
+    files: list
+
+    """
+    try:
+        all_files_in_folder = [f for f in next(os.walk(directory))[2] if not f[0] == '.']
+    except StopIteration:
+        print('SIMBA WARNING: No files found in the {} directory with accepted extensions {}'.format(directory, str(extensions)))
+        raise FileNotFoundError('SIMBA ERROR: No files found in the directory with accepted extensions')
+    all_files_in_folder = [os.path.join(directory, x) for x in all_files_in_folder]
+    accepted_file_paths = []
+    for file_path in all_files_in_folder:
+        _, file_name, ext = get_fn_ext(file_path)
+        if ext.lower() in extensions:
+            accepted_file_paths.append(file_path)
+    if not accepted_file_paths and raise_warning:
+        print('SIMBA WARNING: SimBA could not find any files with accepted extensions {} in the {} directory'.format(extensions, str(directory)))
+
+    return accepted_file_paths
