@@ -3,11 +3,17 @@ __author__ = "Simon Nilsson", "JJ Choong"
 import pandas as pd
 from simba.misc_tools import (check_multi_animal_status,
                               get_fn_ext,
-                              SimbaTimer)
+                              SimbaTimer,
+                              framewise_euclidean_distance)
 from datetime import datetime
 from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
-from simba.read_config_unit_tests import read_config_entry, check_that_column_exist, read_config_file
+from simba.read_config_unit_tests import (read_config_entry,
+                                          read_config_file,
+                                          check_if_filepath_list_is_empty,
+                                          read_project_path_and_file_type)
+from simba.enums import ReadConfig, Paths
 import os, glob
+from numba import jit, prange
 from collections import defaultdict
 from simba.rw_dfs import read_df
 import numpy as np
@@ -34,45 +40,52 @@ class MovementProcessor(object):
     """
 
     def __init__(self,
-                 config_path: str):
+                 config_path: str,
+                 visualization: bool = False,
+                 files: list=None):
 
         self.timer = SimbaTimer()
         self.timer.start_timer()
         self.timestamp = datetime.now().strftime('%Y%m%d%H%M%S')
         self.config = read_config_file(config_path)
-        self.project_path = read_config_entry(self.config, 'General settings', 'project_path', data_type='folder_path')
+        self.project_path, self.file_type = read_project_path_and_file_type(config=self.config)
         self.logs_path = os.path.join(self.project_path, 'logs')
         self.save_path = os.path.join(self.logs_path, 'Movement_log_{}.csv'.format(self.timestamp))
-        self.in_dir = os.path.join(self.project_path, 'csv', 'outlier_corrected_movement_location')
-        self.vid_info_df = read_video_info_csv(os.path.join(self.logs_path, 'video_info.csv'))
-        self.file_type = read_config_entry(self.config, 'General settings', 'workflow_file_type', 'str', 'csv')
+        self.in_dir = os.path.join(self.project_path, Paths.OUTLIER_CORRECTED.value)
+        self.vid_info_df = read_video_info_csv(os.path.join(self.project_path, Paths.VIDEO_INFO.value))
         try:
-            self.animal_cnt = read_config_entry(self.config, 'process movements', 'no_of_animals', 'int')
-            self.p_threshold = read_config_entry(self.config, 'process movements', 'probability_threshold', 'float')
+            self.animal_cnt = read_config_entry(self.config, ReadConfig.PROCESS_MOVEMENT_SETTINGS.value, 'no_of_animals', 'int')
+            self.p_threshold = read_config_entry(self.config, ReadConfig.PROCESS_MOVEMENT_SETTINGS.value, 'probability_threshold', 'float')
         except:
             print('Please analyze movements before visualizing data.')
             raise ValueError('Please analyze movements before visualizing data.')
         self.multiAnimalStatus, self.multiAnimalIDList = check_multi_animal_status(self.config, self.animal_cnt)
         self.bp_dict = defaultdict(list)
         self.bp_columns = []
-        for cnt, animal in enumerate(self.multiAnimalIDList):
-            bp_name = read_config_entry(self.config, 'process movements', 'animal_{}_bp'.format(cnt+1), 'str')
-            if bp_name == 'None':
-                print('SIMBA ERROR: No body-parts found in config [process movements][animal_N_bp]')
-                raise ValueError
-            for c in ['_x', '_y', '_p']:
-                self.bp_dict[animal].append(bp_name + c)
-                self.bp_columns.append(bp_name + c)
-        self.files_found = glob.glob(self.in_dir + '/*.' + self.file_type)
-        if len(self.files_found) == 0:
-            print('SIMBA ERROR: ZERO files found in the {} directory.'.format(self.files_found))
-            raise FileNotFoundError()
+        if not visualization:
+            for cnt, animal in enumerate(self.multiAnimalIDList):
+                bp_name = read_config_entry(self.config, ReadConfig.PROCESS_MOVEMENT_SETTINGS.value, 'animal_{}_bp'.format(cnt+1), 'str')
+                if bp_name == 'None':
+                    print('SIMBA ERROR: No body-parts found in config [process movements][animal_N_bp]')
+                    raise ValueError
+                for c in ['_x', '_y', '_p']:
+                    self.bp_dict[animal].append(bp_name + c)
+                    self.bp_columns.append(bp_name + c)
+            self.files_found = glob.glob(self.in_dir + '/*.' + self.file_type)
+            check_if_filepath_list_is_empty(filepaths=self.files_found,
+                                            error_msg='SIMBA ERROR: Cannot process movement. ZERO data files found in the {} directory.'.format(self.files_found))
+        else:
+            for cnt in range(self.animal_cnt):
+                bp_name = read_config_entry(self.config, ReadConfig.PROCESS_MOVEMENT_SETTINGS.value, 'animal_{}_bp'.format(cnt+1), 'str')
+                if bp_name == 'None':
+                    print('SIMBA ERROR: No body-parts found in config [process movements][animal_N_bp]')
+                    raise ValueError
+                for c in ['_x', '_y', '_p']:
+                    self.bp_dict[self.multiAnimalIDList[cnt]].append(bp_name + c)
+                    self.bp_columns.append(bp_name + c)
+            self.files_found = files
         print('Processing {} video(s)...'.format(str(len(self.files_found))))
 
-    def __euclidean_distance(self, bp_1_x_vals, bp_2_x_vals, bp_1_y_vals, bp_2_y_vals, px_per_mm):
-        series = (np.sqrt((bp_1_x_vals - bp_2_x_vals) ** 2 + (bp_1_y_vals - bp_2_y_vals) ** 2)) / px_per_mm
-        return series
-
     def process_movement(self):
         """
         Method to run movement aggregation computations.
@@ -101,7 +114,10 @@ class MovementProcessor(object):
                 df_shifted = animal_df.shift(1)
                 df_shifted = df_shifted.combine_first(animal_df).add_suffix('_shifted')
                 animal_df = pd.concat([animal_df, df_shifted], axis=1)
-                self.movement = self.__euclidean_distance(animal_df[animal_bps[0]], animal_df[animal_bps[0] + '_shifted'], animal_df[animal_bps[1]], animal_df[animal_bps[1] + '_shifted'], self.px_per_mm)
+                bp_time_1 = animal_df[[animal_bps[0], animal_bps[1]]].values
+                bp_time_2 = animal_df[[animal_bps[0] + '_shifted', animal_bps[1] + '_shifted']].values
+                self.movement = pd.Series(framewise_euclidean_distance(location_1=bp_time_1, location_2=bp_time_2, px_per_mm=self.px_per_mm))
+                self.movement.loc[0] = 0
                 self.movement_dict[video_name][animal_name] = self.movement
                 self.results[video_name][animal_name]['Distance (cm)'] = round((self.movement.sum() / 10), 4)
                 velocity_lst = []
@@ -129,6 +145,6 @@ class MovementProcessor(object):
         self.timer.stop_timer()
         print('SIMBA COMPLETE: Movement log saved in {} (elapsed time: {}s)'.format(self.save_path, self.timer.elapsed_time_str))
 
-#
-# test = MovementProcessor(config_path='/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini')
+# test = MovementProcessor(config_path='/Users/simon/Desktop/envs/troubleshooting/Two_animals_16bps/project_folder/project_config.ini')
 # test.process_movement()
+# test.save_results()
