@@ -2,13 +2,15 @@ __author__ = "Simon Nilsson", "JJ Choong"
 
 import pandas as pd
 from simba.read_config_unit_tests import (check_int,
-                                          check_str)
+                                          check_str,
+                                          check_if_filepath_list_is_empty)
 import os, glob
 import cv2
 from copy import deepcopy
 from simba.misc_tools import (get_fn_ext,
                               SimbaTimer)
 import subprocess
+from simba.enums import Formats
 
 class MultiCropper(object):
     """
@@ -22,7 +24,7 @@ class MultiCropper(object):
         Folder path holding videos to be cropped.
     output_folder: str
         Folder where to store the results.
-    crop_cnt: str
+    crop_cnt: int
         Integer representing the number of videos to produce from every input video.
 
     Notes
@@ -53,11 +55,10 @@ class MultiCropper(object):
         check_str(name='FILE TYPE',value=self.file_type)
         if self.file_type.__contains__('.'): self.file_type.replace(".", "")
         self.files_found = glob.glob(self.input_folder + '/*.{}'.format(self.file_type))
-        if len(self.files_found) == 0:
-            print('SIMBA CROP ERROR: The input direct {} contains ZERO videos in {} format'.format(self.input_folder, self.file_type))
-            raise ValueError('SIMBA CROP ERROR: The input direct {} contains ZERO videos in {} format'.format(self.input_folder, self.file_type))
+        check_if_filepath_list_is_empty(filepaths=self.files_found,
+                                        error_msg='SIMBA CROP ERROR: The input direct {} contains ZERO videos in {} format'.format(self.input_folder, self.file_type))
         if not os.path.exists(self.output_folder): os.makedirs(self.output_folder)
-        self.font_scale, self.space_scale, self.font = 0.02, 1.1, cv2.FONT_HERSHEY_TRIPLEX
+        self.font_scale, self.space_scale, self.font = 0.02, 1.1, Formats.FONT.value
         self.add_spacer = 2
         self.__crop_videos()
 
