@@ -2,6 +2,8 @@ import glob, os
 import pandas as pd
 from collections import OrderedDict
 from datetime import datetime
+from simba.read_config_unit_tests import (check_if_filepath_list_is_empty,
+                                          check_if_dir_exists)
 
 
 class KeypointReorganizer(object):
@@ -35,17 +37,14 @@ class KeypointReorganizer(object):
                  pose_tool: str,
                  file_format: str or None):
 
-        if not os.path.isdir(data_folder):
-            print('SIMBA ERROR: {} is not a valid directory.'.format(str(data_folder)))
-            raise NotADirectoryError
+
+        check_if_dir_exists(in_dir=data_folder)
         self.data_folder, self.pose_tool = data_folder, pose_tool
         self.file_format = file_format
         self.files_found = glob.glob(self.data_folder + '/*.' + file_format)
         self.datetime = str(datetime.now().strftime('%Y%m%d%H%M%S'))
-        if len(self.files_found) < 1:
-            print('SIMBA ERROR: Zero files found of type {} in the {} directory'.format(file_format, data_folder))
-            raise ValueError
-
+        check_if_filepath_list_is_empty(filepaths=self.files_found,
+                                        error_msg='SIMBA ERROR: Zero files found of type {} in the {} directory'.format(file_format, data_folder))
         if file_format == 'h5':
             first_df = pd.read_hdf(self.files_found[0])
             self.header_list = list(first_df.columns)
