@@ -3,7 +3,9 @@ import pandas as pd
 
 def read_df(file_path: str,
             file_type: str,
-            idx=0):
+            idx=0,
+            remove_columns: list or None=None,
+            usecols: list or None=None):
     """
     Helper function to read single data file into memory.
 
@@ -15,6 +17,10 @@ def read_df(file_path: str,
         Type of data. OPTIONS: 'parquet' or 'csv'.
     idx: int,
         Index column location. Default: 0.
+    remove_columns: list or None,
+        If list, remove columns
+    usecols: list or None,
+        If list, keep columns
 
     Returns
     -------
@@ -24,7 +30,7 @@ def read_df(file_path: str,
     try:
         if file_type == 'csv':
             try:
-                df = pd.read_csv(file_path, index_col=idx, low_memory=False)
+                df = pd.read_csv(file_path, index_col=idx, low_memory=False, sep=',')
             except Exception as e:
                 if type(e).__name__ == 'ParserError':
                     print('SIMBA ERROR: SimBA tried to read {} as a comma delimited CSV file and failed. Make sure {} is a utf-8 encoded comma delimited CSV file.'.format(file_path, os.path.basename(file_path)))
@@ -37,6 +43,12 @@ def read_df(file_path: str,
         else:
             print('SIMBA ERROR: The file type ({}) is not recognized. Please set the workflow file type to either csv or parquet'.format(file_type))
             raise ValueError('SIMBA ERROR: The file type is not recognized. Please set the workflow file type to either csv or parquet')
+        if remove_columns:
+            df = df[df.columns[~df.columns.isin(remove_columns)]]
+        if usecols:
+            df = df[df.columns[df.columns.isin(usecols)]]
+        else:
+            pass
         return df
     except FileNotFoundError:
         print('The CSV file could not be located at the following path: ' + str(file_path) + ' . It may be that you missed a step in the analysis. Please generate the file before proceeding.')
