@@ -4,8 +4,12 @@ from simba.read_config_unit_tests import (read_config_file,
                                           check_float,
                                           check_file_exist_and_readable,
                                           check_str)
-from simba.tkinter_functions import Entry_Box, FileSelect, FolderSelect
-from simba.tkinter_functions import hxtScrollbar, DropDownMenu, CreateToolTip
+from simba.tkinter_functions import (Entry_Box,
+                                     FileSelect)
+from simba.tkinter_functions import (hxtScrollbar,
+                                     DropDownMenu)
+from simba.enums import (ReadConfig,
+                         Formats)
 from tkinter import *
 import os, glob
 import pandas as pd
