@@ -14,6 +14,7 @@ from simba.drop_bp_cords import (get_fn_ext,
                                  create_body_part_dictionary,
                                  getBpNames,
                                  getBpHeaders)
+from datetime import datetime
 import itertools
 import cv2
 import pyarrow.parquet as pq
@@ -73,6 +74,7 @@ class SleapCsvImporter(object):
         color_lst = createColorListofList(self.animal_cnt, len(self.x_cols))
         self.video_dir = os.path.join(self.project_path, 'videos')
         self.files_found = glob.glob(data_folder + '/*.csv')
+        self.import_log_path = os.path.join(self.project_path, 'logs', f'data_import_log_{datetime.now().strftime("%Y%m%d%H%M%S")}.csv')
         if len(self.files_found) == 0:
             print('SIMBA ERROR: Zero CSV files found in the data directory ({})'.format(data_folder))
             raise ValueError('SIMBA ERROR: No CSV files found in input directory')
@@ -80,7 +82,8 @@ class SleapCsvImporter(object):
         self.space_scaler, self.radius_scaler, self.res_scaler, self.font_scaler, self.add_spacer, self.frame_no = 40, 10, 1500, 1.2, 2, 1
         self.bp_names_csv_path = os.path.join(self.project_path, 'logs', 'measures', 'pose_configs', 'bp_names', 'project_bp_names.csv')
         self.pose_settings = self.config.get('create ensemble settings', 'pose_estimation_body_parts')
-        if (self.pose_settings is 'user_defined'): self.__update_config_animal_cnt()
+        if (self.pose_settings is 'user_defined'):
+            self.__update_config_animal_cnt()
         self.animal_bp_dict = create_body_part_dictionary(multi_animal_status, self.actor_ids, self.animal_cnt, self.x_cols, self.y_cols, self.p_cols, color_lst)
         if self.animal_cnt > 1:
             self.__update_bp_headers_file()
@@ -109,9 +112,9 @@ class SleapCsvImporter(object):
 
     def __create_first_side_img(self):
         side_img = np.ones((int(self.video_info['height'] / 2), self.video_info['width'], 3))
-        cv2.putText(side_img, 'Current video: ' + self.video_basename, (10, self.vid_space_scale), cv2.FONT_HERSHEY_SIMPLEX, self.vid_font_scale, (255, 255, 255), 3)
+        cv2.putText(side_img, 'Current video: ' + self.video_basename, (10, self.vid_space_scale), cv2.FONT_HERSHEY_SIMPLEX, self.vid_font_scale, (255, 255, 255), 2)
         cv2.putText(side_img, 'Can you assign identities based on the displayed frame ?', (10, int(self.vid_space_scale * (self.add_spacer * 2))), cv2.FONT_HERSHEY_SIMPLEX, self.vid_font_scale, (255, 255, 255), 2)
-        cv2.putText(side_img, 'Press "x" to display new, random, frame', (10, int(self.vid_space_scale * (self.add_spacer * 3))), cv2.FONT_HERSHEY_SIMPLEX, self.vid_font_scale, (255, 255, 0), 3)
+        cv2.putText(side_img, 'Press "x" to display new, random, frame', (10, int(self.vid_space_scale * (self.add_spacer * 3))), cv2.FONT_HERSHEY_SIMPLEX, self.vid_font_scale, (255, 255, 0), 2)
         cv2.putText(side_img, 'Press "c" to continue to start assigning identities using this frame', (10, int(self.vid_space_scale * (self.add_spacer * 4))), cv2.FONT_HERSHEY_SIMPLEX, self.vid_font_scale, (0, 255, 0), 2)
         self.img_concat = np.uint8(np.concatenate((self.img_overlay, side_img), axis=0))
 
@@ -158,7 +161,7 @@ class SleapCsvImporter(object):
 
     def __insert_all_animal_names(self):
         for animal_cnt, animal_data in self.ID_cords.items():
-            cv2.putText(self.new_frame, animal_data['name'], animal_data['cord'], cv2.FONT_HERSHEY_SIMPLEX, self.vid_font_scale, self.animal_bp_dict[animal_data['name']]['colors'][0], 3)
+            cv2.putText(self.new_frame, animal_data['name'], animal_data['cord'], cv2.FONT_HERSHEY_SIMPLEX, self.vid_font_scale, self.animal_bp_dict[animal_data['name']]['colors'][0], 2)
 
     def __initiate_confirm(self):
         cv2.destroyAllWindows()
@@ -215,7 +218,7 @@ class SleapCsvImporter(object):
             animal_1, animal_2 = self.animal_order[click_n]['animal_name'], self.animal_order[click_n1]['animal_name']
             if animal_1 == animal_2:
                 print('SIMBA ERROR: The animal most proximal to click number {} is animal named {}. The animal most proximal to click number {} is also animal {}.'
-                      'Please indicate which animal is which using a video frame where the animals are clearly separated')
+                      'Please indicate which animal is which using a video frame where the animals are clearly separated'.format(click_n, animal_1, click_n1, animal_2))
             else:
                 pass
 
@@ -314,10 +317,10 @@ class SleapCsvImporter(object):
                 else:
                     animal_frm_data = np.full((data.shape[1]), 0.0)
                 results[i][j*animal_frm_data.shape[0]:j*animal_frm_data.shape[0]+animal_frm_data.shape[0]] = animal_frm_data
-
         return results
 
     def initate_import_slp(self):
+        import_log = pd.DataFrame(columns=['VIDEO', 'IMPORT_TIME', 'IMPORT_SOURCE', 'INTERPOLATION_SETTING', 'SMOOTHING_SETTING'])
         for file_cnt, file_path in enumerate(self.files_found):
             _, self.video_basename, _ = get_fn_ext(filepath=file_path)
             print('Analysing {}...'.format(os.path.basename(file_path)))
@@ -358,7 +361,14 @@ class SleapCsvImporter(object):
                 self.__run_interpolation()
             if self.smoothing_settings['Method'] != 'None':
                 self.__run_smoothing()
+            import_log.loc[len(import_log)] = [self.video_basename,
+                                               datetime.now().strftime('%Y%m%d%H%M%S'),
+                                               'SLEAP_CSV',
+                                               str(self.interpolation_settings),
+                                               str(self.smoothing_settings)]
             print('Video "{}" imported...'.format(self.video_basename))
+
+        import_log.to_csv(self.import_log_path)
         print('SIMBA COMPLETE: {} file(s) imported to the SimBA project (project_folder/csv/input_csv directory)'.format(str(len(self.files_found))))
 
 
