@@ -1,10 +1,19 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
 import pandas as pd
-from simba.read_config_unit_tests import read_config_entry, check_that_column_exist, read_config_file
+from simba.read_config_unit_tests import (read_config_entry,
+                                          check_that_column_exist,
+                                          read_config_file,
+                                          check_if_filepath_list_is_empty,
+                                          read_project_path_and_file_type)
 from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
 from datetime import datetime
-from simba.misc_tools import check_multi_animal_status
+from simba.misc_tools import (check_multi_animal_status,
+                              SimbaTimer,
+                              framewise_euclidean_distance)
+from simba.enums import (ReadConfig,
+                         Paths,
+                         Dtypes)
 from simba.drop_bp_cords import create_body_part_dictionary, getBpNames
 import os, glob
 from simba.rw_dfs import read_df
@@ -37,34 +46,30 @@ class TimeBinsMovementAnalyzer(object):
                  config_path: str,
                  bin_length: int):
 
+        self.timer = SimbaTimer()
+        self.timer.start_timer()
         self.bin_length = bin_length
         self.config = read_config_file(config_path)
         self.datetime = datetime.now().strftime('%Y%m%d%H%M%S')
-        self.project_path = read_config_entry(self.config, 'General settings', 'project_path', data_type='folder_path')
-        self.file_type = read_config_entry(self.config, 'General settings', 'workflow_file_type', 'str', 'csv')
-        self.data_in_dir = os.path.join(self.project_path, 'csv', 'outlier_corrected_movement_location')
-        self.vid_info_df = read_video_info_csv(os.path.join(self.project_path, 'logs', 'video_info.csv'))
-        self.datetime = datetime.now().strftime('%Y%m%d%H%M%S')
-        self.animal_cnt = read_config_entry(self.config, 'General settings', 'animal_no', 'int')
+        self.project_path, self.file_type = read_project_path_and_file_type(config=self.config)
+        self.data_in_dir = os.path.join(self.project_path, Paths.OUTLIER_CORRECTED.value)
+        self.vid_info_df = read_video_info_csv(os.path.join(self.project_path, Paths.VIDEO_INFO.value))
+        self.animal_cnt = read_config_entry(self.config, ReadConfig.GENERAL_SETTINGS.value, ReadConfig.ANIMAL_CNT.value, Dtypes.INT.value)
         self.multi_animal_status, self.multi_animal_id_lst = check_multi_animal_status(self.config, self.animal_cnt)
         self.col_headers = []
         for animal_no in range(self.animal_cnt):
-            animal_bp = read_config_entry(self.config, 'process movements', 'animal_{}_bp'.format(str(animal_no + 1)), 'str')
+            animal_bp = read_config_entry(self.config, ReadConfig.PROCESS_MOVEMENT_SETTINGS.value, 'animal_{}_bp'.format(str(animal_no + 1)), Dtypes.STR.value)
             self.col_headers.extend((animal_bp + '_x', animal_bp + '_y'))
         self.x_cols, self.y_cols, self.p_cols = getBpNames(config_path)
         self.x_cols = [x for x in self.x_cols if x in self.col_headers]
         self.y_cols = [x for x in self.y_cols if x in self.col_headers]
         self.files_found = glob.glob(self.data_in_dir + '/*.' + self.file_type)
+        check_if_filepath_list_is_empty(filepaths=self.files_found,
+                                        error_msg='SIMBA ERROR: Cannot analyze movement in time-bins, data directory {} is empty.'.format(self.data_in_dir))
         self.animal_bp_dict = create_body_part_dictionary(self.multi_animal_status, self.multi_animal_id_lst, self.animal_cnt, self.x_cols, self.y_cols, [], [])
         self.animal_combinations = list(itertools.combinations(self.animal_bp_dict, 2))
         print('Processing {} video(s)...'.format(str(len(self.files_found))))
 
-    @staticmethod
-    @jit(nopython=True)
-    def __euclidean_distance(bp_1_x_vals, bp_2_x_vals, bp_1_y_vals, bp_2_y_vals, px_per_mm):
-        series = (np.sqrt((bp_1_x_vals - bp_2_x_vals) ** 2 + (bp_1_y_vals - bp_2_y_vals) ** 2)) / px_per_mm
-        return series
-
     def analyze_movement(self):
         """
         Method for running the movement time-bin analysis. Results are stored in the ``project_folder/logs`` directory
@@ -95,13 +100,17 @@ class TimeBinsMovementAnalyzer(object):
             for animal, data in self.animal_bp_dict.items():
                 movement_col_name = 'Movement {}'.format(animal)
                 x_col, y_col = data['X_bps'][0], data['Y_bps'][0]
-                result_df[movement_col_name] = self.__euclidean_distance(data_df[x_col].values, data_df[x_col + '_shifted'].values, data_df[y_col].values, data_df[y_col + '_shifted'].values, px_per_mm)
-            result_df.iloc[0,:] = 0
+                bp_time_1 = data_df[[x_col, y_col]].values
+                bp_time_2 = data_df[[x_col + '_shifted', y_col + '_shifted']].values
+                result_df[movement_col_name] = pd.Series(framewise_euclidean_distance(location_1=bp_time_1, location_2=bp_time_2, px_per_mm=px_per_mm, centimeter=True))
+                result_df.loc[0, movement_col_name] = 0
             for animal_c in self.animal_combinations:
                 distance_col_name = 'Distance {} {}'.format(animal_c[0], animal_c[1])
                 bp_1_x, bp_1_y = self.animal_bp_dict[animal_c[0]]['X_bps'][0], self.animal_bp_dict[animal_c[0]]['Y_bps'][0]
                 bp_2_x, bp_2_y = self.animal_bp_dict[animal_c[0]]['X_bps'][0], self.animal_bp_dict[animal_c[1]]['Y_bps'][0]
-                result_df[distance_col_name] = self.__euclidean_distance(data_df[bp_1_x].values, data_df[bp_2_x].values, data_df[bp_1_y].values, data_df[bp_2_y].values, px_per_mm)
+                bp_1 = data_df[[bp_1_x, bp_1_y]].values
+                bp_2 = data_df[[bp_2_x, bp_2_y]].values
+                result_df[distance_col_name] = pd.Series(framewise_euclidean_distance(location_1=bp_1, location_2=bp_2, px_per_mm=px_per_mm))
             results_df_lists = [result_df[i:i + bin_length_frames] for i in range(0, result_df.shape[0], bin_length_frames)]
             indexed_df_lst = []
             for bin, results in enumerate(results_df_lists):
@@ -113,11 +122,11 @@ class TimeBinsMovementAnalyzer(object):
             movement_cols = [x for x in indexed_df.columns if x.startswith('Movement ')]
             distance_cols = [x for x in indexed_df.columns if x.startswith('Distance ')]
             for movement_col in movement_cols:
-                movement = indexed_df.groupby(['Time bin #', 'Second'])[movement_col].mean().reset_index()
-                movement_sum = movement.groupby(['Time bin #'])[movement_col].sum()
-                movement_velocity = movement.groupby(['Time bin #'])[movement_col].mean()
-                video_dict[video_name][movement_col + ' (cm)'] = movement_sum.reset_index()
-                video_dict[video_name][movement_col+ ' velocity (cm/s)'] = movement_velocity.reset_index()
+                movement_sum = indexed_df.groupby(['Time bin #'])[movement_col].sum().reset_index()
+                movement_velocity = indexed_df.groupby(['Time bin #', 'Second'])[movement_col].sum().reset_index()
+                movement_velocity = movement_velocity.groupby(['Time bin #'])[movement_col].mean().reset_index()
+                video_dict[video_name][movement_col + ' (cm)'] = movement_sum
+                video_dict[video_name][movement_col+ ' velocity (cm/s)'] = movement_velocity
             for distance_col in distance_cols:
                 video_dict[video_name][distance_col + ' (cm)'] = indexed_df.groupby(['Time bin #'])[distance_col].mean().reset_index()
 
@@ -132,8 +141,8 @@ class TimeBinsMovementAnalyzer(object):
         video_df = pd.concat(self.out_df_lst, axis= 0).sort_values(by=['Video', 'Time bin #']).set_index('Video')
         save_path = os.path.join(self.project_path, 'logs', 'Time_bins_movement_results_' + self.datetime + '.csv')
         video_df.to_csv(save_path)
+        self.timer.stop_timer()
+        print('SIMBA COMPLETE: Movement time-bins results saved at {} (elapsed time: {}s)'.format(save_path, self.timer.elapsed_time_str))
 
-        print('SIMBA COMPLETE: Movement time-bins results saved at project_folder/logs/output/{}'.format(str('Time_bins_movement_results_' + self.datetime + '.csv')))
-
-# test = TimeBinsMovementAnalyzer(config_path='/Users/simon/Desktop/train_model_project/project_folder/project_config.ini', bin_length=15)
+# test = TimeBinsMovementAnalyzer(config_path='/Users/simon/Desktop/envs/troubleshooting/Two_animals_16bps/project_folder/project_config.ini', bin_length=20)
 # test.analyze_movement()
\ No newline at end of file
