@@ -1,5 +1,6 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
+import glob
 import os
 import numpy as np
 import pandas as pd
@@ -19,16 +20,20 @@ from yellowbrick.classifier import ClassificationReport
 import shap
 from simba.drop_bp_cords import GenerateMetaDataFileHeaders
 from tabulate import tabulate
-#from simba.shap_calcs import shap_summary_calculations
 from simba.shap_agg_stats_visualizer import ShapAggregateStatisticsVisualizer
-from simba.read_config_unit_tests import (check_int, check_str, check_float, read_config_entry, check_file_exist_and_readable)
+from simba.read_config_unit_tests import (check_int, check_str,
+                                          check_float,
+                                          read_config_entry)
+from simba.misc_tools import (create_single_color_lst,
+                              SimbaTimer,
+                              detect_bouts)
 import configparser
 import platform
 from sklearn.utils import parallel_backend
 import pickle
 from dtreeviz.trees import tree, dtreeviz
 import matplotlib.pyplot as plt
-import time
+from simba.enums import ReadConfig, Dtypes, MetaKeys
 plt.switch_backend('agg')
 
 def read_all_files_in_folder(file_paths: list,
@@ -36,7 +41,7 @@ def read_all_files_in_folder(file_paths: list,
                              classifier_names=None):
     """
 
-    Helper function to read in all data files in a folder to a cingle pd.DataFrame for downstream ML algorithm.
+    Helper function to read in all data files in a folder to a single pd.DataFrame for downstream ML algorithm.
     Asserts that all classifiers have annotation fields present in concatenated dataframes.
 
     Parameters
@@ -55,7 +60,8 @@ def read_all_files_in_folder(file_paths: list,
 
     """
 
-    start = time.time()
+    timer = SimbaTimer()
+    timer.start_timer()
     df_concat = pd.DataFrame()
     for file in file_paths:
         _, vid_name, _ = get_fn_ext(file)
@@ -76,8 +82,8 @@ def read_all_files_in_folder(file_paths: list,
     if len(df_concat) == 0:
         raise ValueError('ANNOTATION ERROR: SimBA found 0 annotated frames in the project_folder/csv/targets_inserted directory')
     df_concat = df_concat.loc[:, ~df_concat.columns.str.contains('^Unnamed')]
-    elapsed_time = str(round(time.time() - start, 2))
-    print('{} file(s) read in {}s ...'.format(str(len(file_paths)), elapsed_time))
+    timer.stop_timer()
+    print('{} file(s) read (elapsed time: {}s) ...'.format(str(len(file_paths)), timer.elapsed_time_str))
     return df_concat.reset_index(drop=True)
 
 
@@ -101,7 +107,7 @@ def read_in_all_model_names_to_remove(config, model_cnt, clf_name):
 
     annotation_cols_to_remove = []
     for model_no in range(model_cnt):
-        model_name = config.get('SML settings', 'target_name_' + str(model_no+1))
+        model_name = config.get(ReadConfig.SML_SETTINGS.value, 'target_name_' + str(model_no+1))
         if model_name != clf_name:
             annotation_cols_to_remove.append(model_name)
     return annotation_cols_to_remove
@@ -270,6 +276,8 @@ def calc_permutation_importance(x_test: np.array,
 
     """
     print('Calculating feature permutation importances...')
+    timer = SimbaTimer()
+    timer.start_timer()
     p_importances = permutation_importance(clf, x_test, y_test, n_repeats=10, random_state = 0)
     df = pd.DataFrame(np.column_stack([feature_names, p_importances.importances_mean, p_importances.importances_std]), columns=['FEATURE_NAME', 'FEATURE_IMPORTANCE_MEAN', 'FEATURE_IMPORTANCE_STDEV'])
     df = df.sort_values(by=['FEATURE_IMPORTANCE_MEAN'], ascending=False)
@@ -278,6 +286,8 @@ def calc_permutation_importance(x_test: np.array,
     else:
         save_file_path = os.path.join(save_dir, clf_name + '_permutations_importances.csv')
     df.to_csv(save_file_path, index=False)
+    timer.stop_timer()
+    print('Permutation importance calculation complete (elapsed time: {}s) ...'.format(timer.elapsed_time_str))
 
 def calc_learning_curve(x_y_df: pd.DataFrame,
                   clf_name: str,
@@ -317,6 +327,8 @@ def calc_learning_curve(x_y_df: pd.DataFrame,
     """
 
     print('Calculating learning curves...')
+    timer = SimbaTimer()
+    timer.start_timer()
     x_df, y_df = split_df_to_x_y(x_y_df, clf_name)
     cv = ShuffleSplit(n_splits=shuffle_splits, test_size=tt_size)
     if platform.system() == "Darwin":
@@ -335,6 +347,9 @@ def calc_learning_curve(x_y_df: pd.DataFrame,
     else:
         save_file_path = os.path.join(save_dir, clf_name + '_learning_curve.csv')
     results_df.to_csv(save_file_path, index=False)
+    timer.stop_timer()
+    print('Learning curve calculation complete (elapsed time: {}s) ...'.format(timer.elapsed_time_str))
+
 
 def calc_pr_curve(rf_clf,
                   x_df,
@@ -368,6 +383,8 @@ def calc_pr_curve(rf_clf,
     """
 
     print('Calculating PR curves...')
+    timer = SimbaTimer()
+    timer.start_timer()
     p = rf_clf.predict_proba(x_df)[:, 1]
     precision, recall, thresholds = precision_recall_curve(y_df, p, pos_label=1)
     pr_df = pd.DataFrame()
@@ -382,6 +399,9 @@ def calc_pr_curve(rf_clf,
     else:
         save_file_path = os.path.join(save_dir, clf_name + '_pr_curve.csv')
     pr_df.to_csv(save_file_path, index=False)
+    timer.stop_timer()
+    print('Precision-recall curve calculation complete (elapsed time: {}s) ...'.format(timer.elapsed_time_str))
+
 
 def create_example_dt(rf_clf: RandomForestClassifier,
                       clf_name: str,
@@ -540,8 +560,10 @@ def create_x_importance_bar_chart(rf_clf: RandomForestClassifier,
     create_x_importance_log(rf_clf, x_names, clf_name, save_dir)
     importances_df = pd.read_csv(os.path.join(save_dir, clf_name + '_feature_importance_log.csv'))
     importances_head = importances_df.head(n_bars)
-    ax = importances_head.plot.bar(x='FEATURE', y='FEATURE_IMPORTANCE', legend=False, rot=90, fontsize=6)
-    plt.ylabel("Feature importances' (mean decrease impurity)")
+    colors = create_single_color_lst(pallete_name='hot',increments=n_bars, as_rgb_ratio=True)
+    colors = [x[::-1] for x in colors]
+    ax = importances_head.plot.bar(x='FEATURE', y='FEATURE_IMPORTANCE', legend=False, rot=90, fontsize=6, color=colors)
+    plt.ylabel("Feature importances' (mean decrease impurity)", fontsize=6)
     plt.tight_layout()
     if save_file_no != None:
         save_file_path = os.path.join(save_dir, clf_name + '_' + str(save_file_no) + '_feature_importance_bar_graph.png')
@@ -578,9 +600,13 @@ def dviz_classification_visualization(x_train: np.array,
 
     clf = tree.DecisionTreeClassifier(max_depth=5, random_state=666)
     clf.fit(x_train, y_train)
-    svg_tree = dtreeviz(clf, x_train, y_train, target_name=clf_name, feature_names=x_train.columns, orientation="TD", class_names=class_names, fancy=True, histtype='strip', X=None, label_fontsize=12, ticks_fontsize=8, fontname="Arial")
-    save_path = os.path.join(save_dir, clf_name + '_fancy_decision_tree_example.svg')
-    svg_tree.save(save_path)
+    try:
+        svg_tree = dtreeviz(clf, x_train, y_train, target_name=clf_name, feature_names=x_train.columns, orientation="TD", class_names=class_names, fancy=True, histtype='strip', X=None, label_fontsize=12, ticks_fontsize=8, fontname="Arial")
+        save_path = os.path.join(save_dir, clf_name + '_fancy_decision_tree_example.svg')
+        svg_tree.save(save_path)
+    except:
+        print('SIMBA ERROR: Skipping dtreeviz example decision tree visualization. Make sure "graphviz" is installed.')
+
 
 def create_shap_log(ini_file_path: str,
                     rf_clf: RandomForestClassifier,
@@ -626,6 +652,8 @@ def create_shap_log(ini_file_path: str,
     """
 
     print('Calculating SHAP values...')
+    timer = SimbaTimer()
+    timer.start_timer()
     data_df = pd.concat([x_df, y_df], axis=1)
     target_df, nontarget_df = data_df[data_df[y_df.name] == 1], data_df[data_df[y_df.name] == 0]
     if len(target_df) < cnt_present:
@@ -664,6 +692,9 @@ def create_shap_log(ini_file_path: str,
                                           shap_df=out_df_shap,
                                           shap_baseline_value=expected_value,
                                           save_path=save_path)
+    timer.stop_timer()
+    print('SHAP calculations complete (elapsed time: {}s) ...'.format(timer.elapsed_time_str))
+
 
 def print_machine_model_information(model_dict: dict):
     """
@@ -679,11 +710,11 @@ def print_machine_model_information(model_dict: dict):
     None
     """
 
-    table_view = [["Model name", model_dict['Classifier_name']], ["Ensemble method", 'RF'],
-                 ["Estimators (trees)", model_dict['RF_n_estimators']], ["Max features", model_dict['RF_max_features']],
-                 ["Under sampling setting", model_dict['under_sample_setting']], ["Under sampling ratio", model_dict['under_sample_ratio']],
-                 ["Over sampling setting", model_dict['over_sample_setting']], ["Over sampling ratio", model_dict['over_sample_ratio']],
-                 ["criterion", model_dict['RF_criterion']], ["Min sample leaf", model_dict['RF_min_sample_leaf']]]
+    table_view = [["Model name", model_dict[MetaKeys.CLF_NAME.value]], ["Ensemble method", 'RF'],
+                 ["Estimators (trees)", model_dict[MetaKeys.RF_ESTIMATORS.value]], ["Max features", model_dict[MetaKeys.RF_MAX_FEATURES.value]],
+                 ["Under sampling setting", model_dict[ReadConfig.UNDERSAMPLE_SETTING.value]], ["Under sampling ratio", model_dict[ReadConfig.UNDERSAMPLE_RATIO.value]],
+                 ["Over sampling setting", model_dict[ReadConfig.OVERSAMPLE_SETTING.value]], ["Over sampling ratio", model_dict[ReadConfig.OVERSAMPLE_RATIO.value]],
+                 ["criterion", model_dict[MetaKeys.CRITERION.value]], ["Min sample leaf", model_dict[MetaKeys.MIN_LEAF.value]]]
     headers = ["Setting", "value"]
     print(tabulate(table_view, headers, tablefmt="grid"))
 
@@ -780,12 +811,12 @@ def get_model_info(config: configparser.ConfigParser,
             if config.get('SML settings', 'model_path_' + str(n+1)) == 'No file selected':
                 print('SIMBA WARNING: Skipping {} classifier analysis: The classifier path is set to "No file selected"'.format(str(config.get('SML settings', 'target_name_' + str(n + 1)))))
                 continue
-            model_dict[n]['model_path'] = config.get('SML settings', 'model_path_' + str(n+1))
-            model_dict[n]['model_name'] = config.get('SML settings', 'target_name_' + str(n+1))
+            model_dict[n]['model_path'] = config.get(ReadConfig.SML_SETTINGS.value, 'model_path_' + str(n+1))
+            model_dict[n]['model_name'] = config.get(ReadConfig.SML_SETTINGS.value, 'target_name_' + str(n+1))
             check_str('model_name', model_dict[n]['model_name'])
-            model_dict[n]['threshold'] = config.getfloat('threshold_settings', 'threshold_' + str(n+1))
+            model_dict[n]['threshold'] = config.getfloat(ReadConfig.THRESHOLD_SETTINGS.value, 'threshold_' + str(n+1))
             check_float('threshold', model_dict[n]['threshold'], min_value=0.0, max_value=1.0)
-            model_dict[n]['minimum_bout_length'] = config.getfloat('Minimum_bout_lengths', 'min_bout_' + str(n+1))
+            model_dict[n]['minimum_bout_length'] = config.getfloat(ReadConfig.MIN_BOUT_LENGTH.value, 'min_bout_' + str(n+1))
             check_int('minimum_bout_length', model_dict[n]['minimum_bout_length'])
 
         except ValueError:
@@ -817,7 +848,7 @@ def get_all_clf_names(config: configparser.ConfigParser,
     model_names = []
     for i in range(target_cnt):
         entry_name = 'target_name_{}'.format(str(i+1))
-        model_names.append(read_config_entry(config, 'SML settings', entry_name, data_type='str'))
+        model_names.append(read_config_entry(config, ReadConfig.SML_SETTINGS.value, entry_name, data_type=Dtypes.STR.value))
     return model_names
 
 
@@ -874,52 +905,47 @@ def read_pickle(file_path: str) -> object:
         raise pickle.UnpicklingError('SIMBA ERROR: Can not read user-specified classifier file as pickled file.')
     return clf
 
-# df = pd.read_csv('/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/csv/targets_inserted/Together_1.csv', index_col=0)
-# df = df.drop('Sniffing', axis=1)
-# df = drop_bp_cords(df=df, config_path='/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini')
-# clf = pickle.load(open('/Users/simon/Desktop/troubleshooting/train_model_project/models/generated_models/Attack.sav', 'rb'))
-# _ = calc_learning_curve(x_y_df=df,
-#                         clf_name='Attack',
-#                         shuffle_splits=3,
-#                         dataset_splits=5,
-#                         rf_clf=clf,
-#                         tt_size=0.2,
-#                         save_dir='/Users/simon/Desktop/troubleshooting/train_model_project/models/generated_models/model_evaluations')
 
-# # #
-# def calc_learning_curve(x_y_df: pd.DataFrame,
-#                   clf_name: str,
-#                   shuffle_splits: int,
-#                   dataset_splits: int,
-#                   tt_size: float,
-#                   rf_clf: RandomForestClassifier,
-#                   save_dir: str,
-#                   save_file_no=None):
-#     """
-#     Helper to compute random forest learning curves with cross-validation.
-#
-#     Parameters
-#     ----------
-#     x_y_df: pd.DataFrame
-#         Pandas dataframe holding features and targets.
-#     clf_name: str,
-#         Name of the classifier
-#     shuffle_splits: int
-#         Number of cross-validation datasets at each data split.
-#     dataset_splits: int
-#         Number of data splits.
-#     tt_size: float
-#         dataset test size.
-#     rf_clf: RandomForestClassifier
-#         sklearn RandomForestClassifier object.
-#     save_dir: str,
-#         Directory where to save output in csv file format.
-#     save_file_no: int or None.
-#         If integer, represents the count of the classifier within a grid search. If none, the classifier is not
-#         part of a grid search.
-#
-#     Returns
-#     -------
-#     None
-#
-#     """
\ No newline at end of file
+
+def bout_train_test_splitter(x_df: pd.DataFrame,
+                             y_df: pd.Series,
+                             test_size: float):
+    """
+    Helper to split train and test based on annotated `bouts`.
+
+    Parameters
+    ----------
+    x_df:  pd.DataFrame
+        Features
+    y_df: pd.Series
+        Target
+    test_size: float
+        Size of test as ratio of all annotated bouts.
+
+    Returns
+    -------
+    x_train, x_test, y_train, y_test
+    """
+
+    print('Using bout sampling...')
+    def find_bouts(s: pd.Series, type: str):
+        test_bouts_frames, train_bouts_frames = [], []
+        bouts = detect_bouts(pd.DataFrame(s), target_lst=pd.DataFrame(s).columns, fps=-1)
+        print(f'{str(len(bouts))} {type} bouts found...')
+        bouts = list(bouts.apply(lambda x: list(range(int(x['Start_frame']), int(x['End_frame']) + 1)), 1).values)
+        test_bouts_idx = np.random.choice(np.arange(0, len(bouts)), int(len(bouts) * test_size))
+        train_bouts_idx = np.array([x for x in list(range(len(bouts))) if x not in test_bouts_idx])
+        for i in range(0, len(bouts)):
+            if i in test_bouts_idx:
+                test_bouts_frames.append(bouts[i])
+            if i in train_bouts_idx:
+                train_bouts_frames.append(bouts[i])
+        return [i for s in test_bouts_frames for i in s], [i for s in train_bouts_frames for i in s]
+
+    test_bouts_frames, train_bouts_frames = find_bouts(s=y_df, type='behavior present')
+    test_nonbouts_frames, train_nonbouts_frames = find_bouts(s=np.logical_xor(y_df, 1).astype(int), type='behavior absent')
+    x_train = x_df[x_df.index.isin(train_bouts_frames + train_nonbouts_frames)].values
+    x_test = x_df[x_df.index.isin(test_bouts_frames + test_nonbouts_frames)].values
+    y_train = y_df[y_df.index.isin(train_bouts_frames + train_nonbouts_frames)].values
+    y_test = y_df[y_df.index.isin(test_bouts_frames + test_nonbouts_frames)].values
+    return x_train, x_test, y_train, y_test
\ No newline at end of file
