@@ -21,7 +21,10 @@ from simba.misc_tools import (find_video_of_file,
                               create_gantt_img,
                               resize_gantt)
 from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
-from simba.read_config_unit_tests import read_config_entry, read_config_file
+from simba.read_config_unit_tests import (read_config_entry,
+                                          read_config_file,
+                                          read_project_path_and_file_type)
+from simba.enums import ReadConfig, Paths, Dtypes
 
 plt.interactive(True)
 plt.ioff()
@@ -43,7 +46,7 @@ class ValidateModelOneVideo(object):
     d_threshold: float
         classification threshold
     shortest_bout: int
-        Shortest allowed classified bout expressed in milliseconds. E.g., `1000` will remove shift frames classified
+        Allowed classified bout length expressed in milliseconds. E.g., `1000` will shift frames classified
         as containing the behavior, but occuring in a bout shorter than `1000`, from `target present to `target absent`.
     create_gantt: str
         If SimBA should create gantt charts alongside the validation video. OPTIONS: 'None', 'Gantt chart: final frame only (slightly faster)',
@@ -65,15 +68,13 @@ class ValidateModelOneVideo(object):
         self.create_gantt = create_gantt
         self.discrimination_threshold = float(d_threshold)
         self.shortest_bout = shortest_bout
-        self.project_folder = read_config_entry(config=self.config, section='General settings', option='project_path', data_type='folder_path')
-        self.cnt_animals = read_config_entry(config=self.config, section='General settings', option='animal_no', data_type='int')
-        self.file_type = read_config_entry(config=self.config, section='General settings', option='workflow_file_type', data_type='str', default_value='csv')
+        self.project_folder, self.file_type = read_project_path_and_file_type(config=self.config)
+        self.cnt_animals = read_config_entry(config=self.config, section=ReadConfig.GENERAL_SETTINGS.value, option=ReadConfig.ANIMAL_CNT.value, data_type=Dtypes.INT.value)
         self.video_folder = os.path.join(self.project_folder, 'videos')
-        self.output_folder = os.path.join(self.project_folder, 'frames', 'output', 'validation')
+        self.output_folder = os.path.join(self.project_folder, Paths.SINGLE_CLF_VALIDATION.value)
         if not os.path.exists(self.output_folder): os.makedirs(self.output_folder)
-        self.vid_info_df = read_video_info_csv(os.path.join(self.project_folder, 'logs', 'video_info.csv'))
-        vid_info_df = read_video_info_csv(os.path.join(self.project_folder, 'logs', 'video_info.csv'))
-        self.video_settings, self.px_per_mm, self.fps = read_video_info(vid_info_df, self.feature_filename)
+        self.vid_info_df = read_video_info_csv(os.path.join(self.project_folder, Paths.VIDEO_INFO.value))
+        self.video_settings, self.px_per_mm, self.fps = read_video_info(self.vid_info_df, self.feature_filename)
         self.clf_name = os.path.basename(model_path).replace('.sav', '')
         self.vid_output_path = os.path.join(self.output_folder, '{} {}{}'.format(self.feature_filename, self.clf_name, '.avi'))
         self.clf = pickle.load(open(model_path, 'rb'))
