@@ -1,14 +1,18 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
 from tkinter import *
-import platform
 import os, glob
 import pandas as pd
-from simba.misc_tools import get_fn_ext, get_video_meta_data
-from simba.read_config_unit_tests import read_config_file, read_config_entry
-from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
+from simba.misc_tools import (get_fn_ext,
+                              get_video_meta_data)
+from simba.read_config_unit_tests import (read_config_file,
+                                          read_config_entry,
+                                          read_project_path_and_file_type)
+from simba.features_scripts.unit_tests import (read_video_info_csv,
+                                               read_video_info)
+from simba.enums import Paths, ReadConfig, Dtypes
 from simba.get_coordinates_tools_v2 import get_coordinates_nilsson
-from simba.tkinter_functions import onMousewheel, hxtScrollbar, unbindToMousewheel, onFrameConfigure, bindToMousewheel
+from simba.tkinter_functions import hxtScrollbar
 import collections
 
 class VideoInfoTable(object):
@@ -37,16 +41,16 @@ class VideoInfoTable(object):
                  config_path: str):
 
         self.config = read_config_file(config_path)
-        self.project_path = read_config_entry(self.config, 'General settings', 'project_path', data_type='folder_path')
+        self.project_path, _ = read_project_path_and_file_type(config=self.config)
         self.logs_path = os.path.join(self.project_path, 'logs')
         self.video_folder = os.path.join(self.project_path, 'videos')
-        self.vid_info_path = os.path.join(self.logs_path, 'video_info.csv')
+        self.vid_info_path = os.path.join(self.project_path, Paths.VIDEO_INFO.value)
 
         if os.path.isfile(self.vid_info_path):
             self.vid_info_df = read_video_info_csv(self.vid_info_path).reset_index(drop=True)
         else:
             self.vid_info_df = None
-        self.distance_mm = read_config_entry(self.config, 'Frame settings', 'distance_mm', 'float', 0.00)
+        self.distance_mm = read_config_entry(self.config, ReadConfig.FRAME_SETTINGS.value, ReadConfig.DISTANCE_MM.value, Dtypes.FLOAT.value, 0.00)
         self.find_video_files()
         self.video_basename_lst = []
         self.max_char_vid_name = len(max(self.video_paths))
@@ -97,7 +101,11 @@ class VideoInfoTable(object):
             self.videos[name]['px_mm'].set(0)
             self.videos[name]['px_mm_entry'] = Entry(self.video_frm, width=20, textvariable=self.videos[name]['px_mm'])
             if isinstance(self.vid_info_df, pd.DataFrame):
-                prior_data = read_video_info(self.vid_info_df, video_basename)[0]
+                prior_data = None
+                try:
+                    prior_data = read_video_info(self.vid_info_df, video_basename)[0]
+                except ValueError:
+                    pass
                 if prior_data is not None:
                     for value_name, set_name in zip(['fps', 'Resolution_width', 'Resolution_height', 'Distance_in_mm', 'pixels/mm'], ['fps_var', 'width_var', 'height_var', 'distance', 'px_mm']):
                         float_val = self.__check_that_value_is_numeric(value=prior_data[value_name].values[0], value_name=value_name, video_name=prior_data['Video'].values[0])
@@ -192,7 +200,7 @@ class VideoInfoTable(object):
         self.video_df.drop_duplicates(subset=['Video'], inplace=True)
         self.video_df = self.video_df.set_index('Video')
         try:
-            self.video_df.to_csv(os.path.join(self.logs_path, 'video_info.csv'))
+            self.video_df.to_csv(os.path.join(self.project_path, Paths.VIDEO_INFO.value))
         except PermissionError:
             print('SIMBA PERMISSION ERROR: SimBA tried to write to project_folder/logs/video_info.csv, but was not allowed. If this file is open in another program, tru closing it.')
             raise PermissionError()
