@@ -6,6 +6,7 @@ import cv2
 from pathlib import Path
 from PIL import Image
 from simba.extract_frames_fast import video_to_frames
+from simba.enums import Formats, Paths
 import re
 import subprocess
 import simba
@@ -71,7 +72,7 @@ def clahe_enhance_video(file_path: str):
     dir, file_name, file_ext = get_fn_ext(filepath=file_path)
     save_path = os.path.join(dir, 'CLAHE_{}.avi'.format(file_name))
     video_meta_data = get_video_meta_data(file_path)
-    fourcc = cv2.VideoWriter_fourcc(*'XVID')
+    fourcc = cv2.VideoWriter_fourcc(*Formats.AVI_CODEC.value)
     print('Applying CLAHE on video {}, this might take awhile...'.format(file_name))
     cap = cv2.VideoCapture(file_path)
     writer = cv2.VideoWriter(save_path, fourcc, video_meta_data['fps'], (video_meta_data['height'], video_meta_data['width']), 0)
